@@ -29,7 +29,8 @@ import io.netty.buffer.ByteBuf;
 
 public interface InformationElement {
 
-    Value<?> parse(final Session.Resolver resolver,
+    Value<?> parse(final InformationElementDatabase database,
+                   final Session.Resolver resolver,
                    final ByteBuf buffer) throws InvalidPacketException, MissingTemplateException;
 
     String getName();
