@@ -23,6 +23,7 @@ package org.opennms.netmgt.snmpinterfacepoller;
 
 
 import org.apache.commons.lang.StringUtils;
+import org.opennms.core.logging.Logging;
 import org.opennms.core.network.IPAddress;
 import org.opennms.core.network.IPAddressRange;
 import org.opennms.core.utils.ParameterMap;
@@ -43,7 +44,9 @@ import org.opennms.netmgt.snmpinterfacepoller.pollable.PollableSnmpInterface;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import java.util.*;
+import java.util.HashMap;
+import java.util.Map;
+import java.util.concurrent.ExecutorService;
 
 /**
  * SnmpPoller daemon class
@@ -139,7 +142,6 @@ public class SnmpPoller extends AbstractServiceDaemon {
     protected void onStart() {
         // get the category logger
         // start the scheduler
-        //
         try {
             LOG.debug("onStart: Starting SNMP Interface Poller scheduler");
 
@@ -200,20 +202,25 @@ public class SnmpPoller extends AbstractServiceDaemon {
     /** {@inheritDoc} */
     @Override
     protected void onInit() {
-        
+
         createScheduler();
-        
-        // Schedule the interfaces currently in the database
-        //
-        try {
-            LOG.debug("onInit: Scheduling existing SNMP interfaces polling");
-            scheduleExistingSnmpInterface();
-        } catch (Throwable sqlE) {
-            LOG.error("onInit: Failed to schedule existing interfaces", sqlE);
-        }
+
+        // Schedule the interfaces currently in the database asynchronously
+        // to avoid blocking daemon initialization
+        ExecutorService executor = getExecutorService();
+        executor.execute(() -> {
+            Logging.withPrefix("snmp-poller", () -> {
+                try {
+                    LOG.debug("onInit: Scheduling existing SNMP interfaces polling");
+                    scheduleExistingSnmpInterfaces();
+                } catch (Throwable sqlE) {
+                    LOG.error("onInit: Failed to schedule existing interfaces", sqlE);
+                }
+            });
+        });
 
         m_initialized = true;
-        
+
     }
         
     /**
@@ -221,47 +228,51 @@ public class SnmpPoller extends AbstractServiceDaemon {
      *
      * @param ipaddr a {@link java.lang.String} object.
      */
-    protected void scheduleNewSnmpInterface(String ipaddr) {
- 
-    	for (OnmsIpInterface iface : getNetwork().getContext().getPollableNodesByIp(ipaddr)) {
-            schedulePollableInterface(iface);    		
-    	}
-                
+    protected void scheduleNewSnmpInterfaces(String ipaddr) {
+        getNetwork().getContext().getPollableNodesByIp(ipaddr)
+                .forEach(this::schedulePollableInterfaceAsync);
     }
     
     /**
      * <p>scheduleExistingSnmpInterface</p>
      */
-    protected void scheduleExistingSnmpInterface() {
-        
-    	for (OnmsIpInterface iface : getNetwork().getContext().getPollableNodes()) {
-            schedulePollableInterface(iface);    		
-    	}
+    protected void scheduleExistingSnmpInterfaces() {
+        getNetwork().getContext().getPollableNodes()
+                        .forEach(this::schedulePollableInterfaceAsync);
     }   
 
+    protected void schedulePollableInterfaceAsync(OnmsIpInterface ipInterface) {
+        ExecutorService executor = getExecutorService();
+        executor.execute(() -> schedulePollableInterface(ipInterface));
+    }
     /**
      * <p>schedulePollableInterface</p>
      *
      * @param iface a {@link org.opennms.netmgt.model.OnmsIpInterface} object.
      */
     protected void schedulePollableInterface(OnmsIpInterface iface) {
-        String ipaddress = iface.getIpAddress().getHostAddress();
-        String netmask = null;
-        // netmask is nullable
-        if (iface.getNetMask() != null) {
-            netmask = iface.getNetMask().getHostAddress();
-        }
-        Integer nodeid = iface.getNode().getId();
-        String location = getNetwork().getContext().getLocation(nodeid);
-        if (ipaddress != null && !ipaddress.equals("0.0.0.0")) {
-            String pkgName = getPollerConfig().getPackageName(ipaddress);
-            if (pkgName != null) {
-                LOG.debug("Scheduling snmppolling for node: {} ip address: {} - Found package interface with name: {}", nodeid, ipaddress, pkgName);
-                scheduleSnmpCollection(getNetwork().create(nodeid,ipaddress,netmask,pkgName), pkgName, location);
-            } else if (!getPollerConfig().useCriteriaFilters()) {
-                LOG.debug("No SNMP Poll Package found for node: {} ip address: {}. - Scheduling according with default interval", nodeid, ipaddress);
-                scheduleSnmpCollection(getNetwork().create(nodeid, ipaddress,netmask, "null"), "null", location);
+
+        try {
+            String ipaddress = iface.getIpAddress().getHostAddress();
+            String netmask = null;
+            // netmask is nullable
+            if (iface.getNetMask() != null) {
+                netmask = iface.getNetMask().getHostAddress();
             }
+            Integer nodeid = iface.getNode().getId();
+            String location = getNetwork().getContext().getLocation(nodeid);
+            if (ipaddress != null && !ipaddress.equals("0.0.0.0")) {
+                String pkgName = getPollerConfig().getPackageName(ipaddress);
+                if (pkgName != null) {
+                    LOG.debug("Scheduling snmppolling for node: {} ip address: {} - Found package interface with name: {}", nodeid, ipaddress, pkgName);
+                    scheduleSnmpCollection(getNetwork().create(nodeid, ipaddress, netmask, pkgName), pkgName, location);
+                } else if (!getPollerConfig().useCriteriaFilters()) {
+                    LOG.debug("No SNMP Poll Package found for node: {} ip address: {}. - Scheduling according with default interval", nodeid, ipaddress);
+                    scheduleSnmpCollection(getNetwork().create(nodeid, ipaddress, netmask, "null"), "null", location);
+                }
+            }
+        } catch (Exception e) {
+            LOG.error("Error occurred while scheduling snmppoll for interface {}", iface);
         }
     }
     
@@ -394,7 +405,7 @@ public class SnmpPoller extends AbstractServiceDaemon {
             if (getNetwork().hasPollableInterface(ipaddr.toDbString())) {
                 LOG.debug("reloadSnmpConfig: recreating the Interface to poll: {}", ipaddr);
                 getNetwork().delete(ipaddr.toDbString());
-                scheduleNewSnmpInterface(ipaddr.toDbString());
+                scheduleNewSnmpInterfaces(ipaddr.toDbString());
             } else {
                 LOG.debug("reloadSnmpConfig: no Interface found for ipaddr: {}", ipaddr);
             }
@@ -412,7 +423,7 @@ public class SnmpPoller extends AbstractServiceDaemon {
         try {
             getPollerConfig().update();
             getNetwork().deleteAll();
-            scheduleExistingSnmpInterface();
+            scheduleExistingSnmpInterfaces();
         } catch (Throwable e) {
             LOG.error("Update SnmpPoller configuration file failed",e);
         }
@@ -431,7 +442,7 @@ public class SnmpPoller extends AbstractServiceDaemon {
         
         for (IParm parm : event.getParmCollection()){
             if (parm.isValid() && parm.getParmName().equals("newPrimarySnmpAddress")) {
-                scheduleNewSnmpInterface(parm.getValue().getContent());
+                scheduleNewSnmpInterfaces(parm.getValue().getContent());
                 return;
             }
         }
@@ -486,7 +497,7 @@ public class SnmpPoller extends AbstractServiceDaemon {
     public void serviceGainedHandler(IEvent event) {
         if (event.getService().equals(getPollerConfig().getService())) {
             getPollerConfig().rebuildPackageIpListMap();
-            scheduleNewSnmpInterface(event.getInterface());
+            scheduleNewSnmpInterfaces(event.getInterface());
         }
     }
 
@@ -566,4 +577,7 @@ public class SnmpPoller extends AbstractServiceDaemon {
         getNetwork().suspend(Long.valueOf(event.getNodeid()).intValue());
     }
 
+    private ExecutorService getExecutorService() {
+        return m_scheduler.getRunner();
+    }
 }
